#!/usr/bin/env python

from typing import Iterable

import boto3
from botocore.config import Config


def get_ecr_image_sizes():
    ecr_client = boto3.client("ecr", config=Config(retries={"mode": "standard"}))
    for repository_name in get_ecr_repositories():
        image_count = 0
        total_image_size = 0
        params = {"repositoryName": repository_name}
        while True:
            res = ecr_client.describe_images(**params)
            for detail in res["imageDetails"]:
                image_count += 1
                total_image_size += detail["imageSizeInBytes"]
            if "nextToken" not in res:
                break
            params["nextToken"] = res["nextToken"]
        print(f"{image_count},{total_image_size},{repository_name}")


def get_ecr_repositories() -> Iterable[str]:
    ecr_client = boto3.client("ecr", config=Config(retries={"mode": "standard"}))
    params = {}
    while True:
        res = ecr_client.describe_repositories(**params)
        for repository in res["repositories"]:
            yield repository["repositoryName"]
        if "nextToken" not in res:
            break
        params["nextToken"] = res["nextToken"]


def main():
    get_ecr_image_sizes()


if __name__ == "__main__":
    main()
